GetBaseCertsGraph <- function(Cert_PerCountry, year){
  graph1 <- ggplot2::qplot(main = "Countries with above average number of companies certified with 27001 (2012)",
                           x = reorder(country_short,X2012),
                           y = X2012,
                           xlab = "Country",
                           ylab = "Number of certifications",
                           data = Cert_PerCountry[Cert_PerCountry$X2012 > mean(Cert_PerCountry$X2012),],
                           geom = "col",
                           fill = Continent)
  graph1
}

GetAttacksEvolution <- function(Attacks){

  attacks.range <- Attacks[Attacks$Date < "2016-01-01" & Attacks$Date >= "2012-01-01",]

  attacks.range$Year <- as.numeric(format(attacks.range$Date, "%Y"))

  attacks.range <- mutate(attacks.range, Year = format(attacks.range$Date, "%Y")) %>% group_by(Year)
  attacks.range <- as.data.frame(table(attacks.range$Year))
  colnames(attacks.range) <- c("Year","Attacks")

  graph1 <- ggplot2::qplot(main = "Countries with above average number of companies certified with 27001 (2012)",
                           x = attacks.range$Year,
                           y = attacks.range$Attacks,
                           group = 1,
                           xlab = "Years",
                           ylab = "Number of attacks",
                           data = attacks.range,
                           geom = "line") + geom_point() + geom_smooth( method = lm, se = FALSE)

  graph1

}


#' Return every graph used in the report file
#'
#' @param Cert_PerCountry data.frame with the processed data of ISO 27001 certifications
#' @param Attacks data.frame with the processed data of cyberattacks
#'
#' @return data.frame
#' @export
GetReportGraphs <- function(Cert_PerCountry,Attacks) {
  #2012
  graph1 <- ggplot2::qplot(main = "Countries with above average number of companies certified with 27001 (2012)",
                  x = reorder(country_short,X2012),
                  y = X2012,
                  xlab = "Country",
                  ylab = "Number of certifications",
                  data = Cert_PerCountry[Cert_PerCountry$X2012 > mean(Cert_PerCountry$X2012),],
                  geom = "col",
                  fill = Continent)

  attacks2k12 <- Attacks[Attacks$Date < "2013-01-01" & Attacks$Date >= "2012-01-01",]
  frameAttacks2k12 <- as.data.frame(table(attacks2k12$Country))
  colnames(frameAttacks2k12) <- c("Country","Attacks")
  graph2 <- ggplot2::qplot(main = "Countries with above average number of cyberattacks (2012)",
                  x = reorder(Country,Attacks),
                  y = Attacks,
                  xlab = "Country",
                  ylab = "Number of attacks",
                  data = frameAttacks2k12[frameAttacks2k12$Attacks > mean(frameAttacks2k12$Attacks),],
                  geom = "col",
                  fill = Continent)

  Attacks2012ByMonth <- mutate(attacks2k12, month = format(attacks2k12$Date, "%m")) %>% group_by(month)
  Attack2012FreqByMonth <- as.data.frame(table(Attacks2012ByMonth$month))
  colnames(Attack2012FreqByMonth) <- c("Month", "Attacks")
  graph3 <- ggplot2::qplot(x = as.numeric(Month),
                  y = Attacks,
                  main = "Global cyberattack progression by month (2012)",
                  data = Attack2012FreqByMonth,
                  geom = c("point", "smooth"),
                  xlim = c(1,12),
                  xlab = "Month") + ggplot2::scale_x_continuous(breaks = 1:12)

  #2013
  graph4 <- ggplot2::qplot(main = "Countries with above average number of companies certified with 27001 (2013)",
                  x = reorder(country_short,X2013),
                  y = X2013,
                  xlab = "Country",
                  ylab = "Number of certifications",
                  data = Cert_PerCountry[Cert_PerCountry$X2013 > mean(Cert_PerCountry$X2013),]
                  , geom = "col",
                  fill = Continent)
  attacks2k13 <- Attacks[Attacks$Date < "2014-01-01" & Attacks$Date >= "2013-01-01",]
  frameAttacks2k13 <- as.data.frame(table(attacks2k13$Country))
  colnames(frameAttacks2k13) <- c("Country","Attacks")
  graph5 <- ggplot2::qplot(main = "Countries with above average number of cyberattacks (2013)",
                  x = reorder(Country,Attacks),
                  y = Attacks,
                  xlab = "Country",
                  ylab = "Number of attacks",
                  data = frameAttacks2k13[frameAttacks2k13$Attacks > mean(frameAttacks2k13$Attacks),]
                  , geom = "col",
                  fill = Continent)

  Attacks2013ByMonth <- mutate(attacks2k13, month = format(attacks2k13$Date, "%m")) %>% group_by(month)
  Attack2013FreqByMonth <- as.data.frame(table(Attacks2013ByMonth$month))
  colnames(Attack2013FreqByMonth) <- c("Month", "Attacks")
  graph6 <- ggplot2::qplot(x = as.numeric(Month),
                  y = Attacks,
                  main = "Global cyberattack progression by month (2013)",
                  data = Attack2013FreqByMonth,
                  geom = c("point", "smooth"),
                  xlim = c(1,12),
                  xlab = "Month") + ggplot2::scale_x_continuous(breaks = 1:12)

  #2014
  graph7 <- ggplot2::qplot(main = "Countries with above average number of companies certified with 27001 (2014)",
                  x = reorder(country_short,X2014),
                  y = X2014,
                  xlab = "Country",
                  ylab = "Number of certifications",
                  data = Cert_PerCountry[Cert_PerCountry$X2014 > mean(Cert_PerCountry$X2014),]
                  , geom = "col",
                  fill = Continent)
  attacks2k14 <- Attacks[Attacks$Date < "2015-01-01" & Attacks$Date >= "2014-01-01",]
  frameAttacks2k14 <- as.data.frame(table(attacks2k14$Country))
  colnames(frameAttacks2k14) <- c("Country","Attacks")
  graph8 <- ggplot2::qplot(main = "Countries with above average number of cyberattacks (2014)",
                  x = reorder(Country,Attacks),
                  y = Attacks,
                  xlab = "Country",
                  ylab = "Number of attacks",
                  data = frameAttacks2k14[frameAttacks2k14$Attacks > mean(frameAttacks2k14$Attacks),]
                  , geom = "col",
                  fill = Continent)

  Attacks2014ByMonth <- mutate(attacks2k14, month = format(attacks2k14$Date, "%m")) %>% group_by(month)
  Attack2014FreqByMonth <- as.data.frame(table(Attacks2014ByMonth$month))
  colnames(Attack2014FreqByMonth) <- c("Month", "Attacks")
  graph9 <- ggplot2::qplot(x = as.numeric(Month),
                  y = Attacks,
                  main = "Global cyberattack progression by month (2014)",
                  data = Attack2014FreqByMonth,
                  geom = c("point", "smooth"),
                  xlim = c(1,12),
                  xlab = "Month") + ggplot2::scale_x_continuous(breaks = 1:12)

  #2015
  graph10 <- ggplot2::qplot(main = "Countries with above average number of companies certified with 27001 (2015)",
                  x = reorder(country_short,X2015),
                  y = X2015,
                  xlab = "Country",
                  ylab = "Number of certifications",
                  data = Cert_PerCountry[Cert_PerCountry$X2015 > mean(Cert_PerCountry$X2015),]
                  , geom = "col",
                  fill = Continent)
  attacks2k15 <- Attacks[Attacks$Date < "2016-01-01" & Attacks$Date >= "2015-01-01",]
  frameAttacks2k15 <- as.data.frame(table(attacks2k15$Country))
  colnames(frameAttacks2k15) <- c("Country","Attacks")
  graph11 <- ggplot2::qplot(main = "Countries with above average number of cyberattacks (2015)",
                  x = reorder(Country,Attacks),
                  y = Attacks,
                  xlab = "Country",
                  ylab = "Number of attacks",
                  data = frameAttacks2k15[frameAttacks2k15$Attacks > mean(frameAttacks2k15$Attacks),]
                  , geom = "col",
                  fill = Continent)

  Attacks2015ByMonth <- mutate(attacks2k15, month = format(attacks2k15$Date, "%m")) %>% group_by(month)
  Attack2015FreqByMonth <- as.data.frame(table(Attacks2015ByMonth$month))
  colnames(Attack2015FreqByMonth) <- c("Month", "Attacks")
  graph12 <- ggplot2::qplot(x = as.numeric(Month),
                  y = Attacks,
                  main = "Global cyberattack progression by month (2015)",
                  data = Attack2015FreqByMonth,
                  geom = c("point", "smooth"),
                  xlim = c(1,12),
                  xlab = "Month") + ggplot2::scale_x_continuous(breaks = 1:12)




  list(graph1,graph2,graph3,graph4,graph5,graph6,graph7,graph8,graph9,graph10,graph11,graph12)
}
